<img src="/example_images/SPLOTCH_logo.png" alt="drawing" width="500"/>

**Simple PLOTs, Contours and Histograms** is a small package with wrapper functions designed to simplify plotting calls from matplotlib.

 Histograms                | Contour Plots             | Colorbars                 
:---:|:---:|:---:
| ![hist](/example_images/example_hist.png) |  ![contours](/example_images/example_contours.png) | ![colorbar](/example_images/example_colorbar.png) |

| Sector Plots             | Corner Plots              | Subplots                
:---:|:---:|:---:
| ![sector](/example_images/example_sectorplot.png) | ![corner](/example_images/example_cornerplot.png)  |  ![subplots](/example_images/example_subplots.png) | 


The package is available in for installation using `>pip install splotch`, though you may get the lastest stable version using `>pip install git+https://github.com/MBravoS/splotch.git@master`, or the latest development version using `>pip install git+https://github.com/MBravoS/splotch.git@devel`.

The documentation is [splotch's readthedocs page](https://splotch.readthedocs.io/en/latest/). 

*Current version*: 0.5.10.1

*Planned releases*:
* Addition on unique colour maps (0.6.0.0)
* Addition of legend customisation function (0.7.0.0).
* Re-work for PEP coding style compliance (using PyLint) (0.8.0.0).
* Add basic tests with Travis (0.9.0.0).
* Improved documentation and first version release (1.0.0.0).
